package Crypt::OpenSSL3::BIO::PollDescriptor;
$Crypt::OpenSSL3::BIO::PollDescriptor::VERSION = '0.009';
use strict;
use warnings;

use Crypt::OpenSSL3;

1;

# ABSTRACT: A polldescriptor of a BIO

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::BIO::PollDescriptor - A polldescriptor of a BIO

=head1 VERSION

version 0.009

=head1 METHODS

=head2 new

=head2 type

=head2 fd

=head1 CONSTANTS

=over 4

=item CUSTOM_START

=item TYPE_NONE

=item TYPE_SOCK_FD

=back

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2025 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
