package Crypt::OpenSSL3::ASN1;
$Crypt::OpenSSL3::ASN1::VERSION = '0.009';
use strict;
use warnings;

1;

#ABSTRACT: ASN1 constants

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::ASN1 - ASN1 constants

=head1 VERSION

version 0.009

=over 41

=item EOC

=item BOOLEAN

=item INTEGER

=item BIT_STRING

=item OCTET_STRING

=item NULL

=item OBJECT

=item OBJECT_DESCRIPTOR

=item EXTERNAL

=item REAL

=item ENUMERATED

=item UTF8STRING

=item SEQUENCE

=item SET

=item NUMERICSTRING

=item PRINTABLESTRING

=item T61STRING

=item TELETEXSTRING

=item VIDEOTEXSTRING

=item IA5STRING

=item UTCTIME

=item GENERALIZEDTIME

=item GRAPHICSTRING

=item ISO64STRING

=item VISIBLESTRING

=item GENERALSTRING

=item UNIVERSALSTRING

=item BMPSTRING

=back

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2025 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
