package Crypt::OpenSSL3::NID;
$Crypt::OpenSSL3::NID::VERSION = '0.009';
use strict;
use warnings;

1;

# ABSTRACT: OpenSSL NIDs

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::NID - OpenSSL NIDs

=head1 VERSION

version 0.009

=head1 METHODS

=head2 create

=head2 eq

=head2 from_long_name

=head2 from_short_name

=head2 from_text

=head2 get_long_name

=head2 get_short_name

=head2 is_undef

=head2 raw

=head2 to_object

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2025 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
